@@ -11,24 +11,12 @@
 # This script based on https://github.com/rocky/python-uncompyle6/blob/master/__pkginfo__.py
 #
 
-# stdlib
-import pathlib
-
 __all__ = [
-		"__copyright__",
 		"__version__",
-		"repo_root",
-		"install_requires",
 		"extras_require",
 		]
 
-__copyright__ = """
-2019-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
-"""
-
-__version__ = "2.9.0"
-repo_root = pathlib.Path(__file__).parent
-install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
+__version__ = "2.9.1"
 extras_require = {
 		"dates": ["pytz>=2019.1"],
 		"testing": ["pytest>=6.2.0", "pytest-regressions>=2.0.2"],
